@@ -23,6 +23,6 @@
 
 off_t cbm_alignment(void);
 off_t cbm_size(void);
-int cbm_write(off_t base, int fd);
+int cbm_write(struct exfat_dev* dev, off_t base);
 
 #endif /* ifndef MKFS_CBM_H_INCLUDED */
